; -*-Emacs-Lisp-*-
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; File:         stack-frames.el
; RCS:          $Header: $
; Description:  Portions of Carl; Edman's frame.el and .emacs
; Author:       Meinhard E. Mayer, Department of Physics, U. C. Irvine
; Created:      Sat Oct  9 18:20:26 1993
; Modified:     Sat Oct  9 18:40:33 1993 (Meinhard E. Mayer) hardy@golem
; Language:     Emacs-Lisp
; Package:      N/A
; Status:       Experimental
;
; (C) Copyright 1993, but otherwise this file is perfect freeware.
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; These are the modifications to the make-frame functions, 
;;; taken from Carl Edman's frame.el for the NeXTSTEP+X 
;;; version of emacs-19.19, soon to be released. Loading it allows one to
;;; have successively created frames "stacked" so  that
;;; the title bars and menu-bars remain visible. This facilitates
;;; using the mouse to move from one frame to another.
;;; The amount of displacement can be modified by changing the parameters
;;; in the last defun.   Carl Edman deserves all the credit for this. 
;;; All I did was cut and paste!  
;;; You need to either load this file, or add the line
;;; (require 'stack-frames)  to your .emacs file


(defun make-frame (&optional parameters)
  "Create a new frame, displaying the current buffer.

Optional argument PARAMETERS is an alist of parameters for the new
frame.  Specifically, PARAMETERS is a list of pairs, each having one
of the following forms:

\(name . STRING)	- The frame should be named STRING.

\(height . NUMBER) - The frame should be NUMBER text lines high.  If
	this parameter is present, the width parameter must also be
	given.

\(width . NUMBER) - The frame should be NUMBER characters in width.
	If this parameter is present, the height parameter must also
	be given.

\(minibuffer . t) - the frame should have a minibuffer
\(minibuffer . nil) - the frame should have no minibuffer
\(minibuffer . only) - the frame should contain only a minibuffer
\(minibuffer . WINDOW) - the frame should use WINDOW as its minibuffer window.

The documentation for the function `x-create-frame' describes
additional frame parameters that Emacs recognizes for X window frames.
The documentation for the function 'dps-create-frame' does the same
for DPS window frames."
  (interactive)
  (let ((nframe))
    (run-hooks 'before-make-frame-hook)
    (setq nframe (funcall frame-creation-function parameters))
    (run-hooks 'after-make-frame-hook)
    nframe))
;;; This portion could optionally go into your .emacs, after 
;;; stack-frames is loaded

(add-hook 'before-make-frame-hook
          '(lambda ()
             (let ((left (cdr (assq 'left (frame-parameters (selected-frame)))))
                   (top (cdr (assq 'top (frame-parameters (selected-frame))))))
               (cond
                ((or (assq 'top parameters) (assq 'left parameters)))
                ((or (not left) (not top)))
                (t
                 (setq parameters (cons (cons 'left (+ left 15))
                                        (cons (cons 'top (+ top 15))
                                              parameters))))))))

(provide 'stack-frames)
;;; stack-frames.el ends here
